@@ -4,10 +4,10 @@ from .fill import Fill
 from .flex import Flex
 from .hr import HR
 from .line import Line
-from .pretty import pretty
-from .pretty_exception import PrettyException
-from .printer import Flattener, Printer
 from .table import Table, CellDfn
 from .text import Text
 from . import context
-print = Flattener()
+from .pretty_exception import PrettyException
+from .pretty import pretty
+from .printer.stream import StringPrinter
+from .printer import Printer
