@@ -1,10 +1,7 @@
 import pytest
-from print_ext.flex import Flex
-from print_ext.borders import Bdr
-from print_ext.fill import Fill
-from print_ext.text import Text
-from print_ext.line import Line, SMark as SM
-from .testutil import debug_dump, styled, printer
+from print_ext import Flex, Bdr, Fill, Text, Line, StringPrinter
+from print_ext.line import SMark as SM
+from .testutil import debug_dump, styled
 
 def f(o, w,h):
     return ','.join(map(str, o.flatten(w=w, h=h)))
@@ -113,8 +110,7 @@ def test_flex_passthrough():
 
 
 def test_flex_with_border():
-    o,p = printer()
+    p = StringPrinter()
     f = Flex('1\t', Bdr('The quick \nbrown fox'), '\t', 'x\t')
     p(f)
-    print(o.getvalue())
-    assert(o.getvalue() == '1┌──────────┐x\n │The quick │\n │brown fox │\n └──────────┘\n')
+    assert(str(p) == '1┌──────────┐x\n │The quick │\n │brown fox │\n └──────────┘\n')
